pytilities.event

Package pytilities :: Package event |
[hide private]
[frames] | no frames]

# Package event

source code

Delegation utilities

Classes:

> Dispatcher
>   Utility class for dispatching events to handlers.
> DispatcherSwitch
>   Provides a single interface to multiple event dispatchers.
> RestrictedDispatcher
>   Dispatcher wrapper that filters the list of supported events.

Decorators:

> dispatcher
>   Installs a Dispatcher on an AttributeCollectionBase.
> dispatcher_switch
>   Installs a DispatcherSwitch on an AttributeCollectionBase.

Submodules | [hide private]
pytilities.event.decorators: Various decorators to ease event dispatching. pytilities.event.dispatcher_ pytilities.event.dispatcherswitch pytilities.event.restricteddispatcher

Variables | [hide private]
| __package__ = ``'``pytilities.event``'``